@@ -2,11 +2,11 @@ package org.gcube.applicationsupportlayer.social;
 
 import java.util.Date;
 import java.util.List;
+import java.util.Set;
 
 import org.gcube.common.homelibrary.home.workspace.WorkspaceFolder;
 import org.gcube.common.homelibrary.home.workspace.WorkspaceItem;
 import org.gcube.common.homelibrary.home.workspace.WorkspaceSharedFolder;
-import org.gcube.portal.databook.shared.ApplicationProfile;
 import org.gcube.portal.databook.shared.NotificationType;
 import org.gcube.portal.databook.shared.RunningJob;
 /**
@@ -167,6 +167,7 @@ public interface NotificationsManager {
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
 	boolean notifyDeletedCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate);
+	
 	/**
 	 * use to notify a user that someone created this post
 	 * 
@@ -175,7 +176,21 @@ public interface NotificationsManager {
 	 * @param feedText the liked feed text or a portion of it
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
+	@Deprecated
 	boolean notifyPost(String userIdToNotify, String feedid, String feedText, String ... hashtags);
+	
+	/**
+	 * use to notify a user that someone created this post
+	 * 
+	 * @param userIdToNotify the user you want to notify
+	 * @param feedid the liked feedid 
+	 * @param feedText the liked feed text or a portion of it
+	 * @param mentionedVREGroups the names of the mentioned vre's groups, if any
+	 * @param hashtags the set of hashtags in the post, if any
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyPost(String userIdToNotify, String feedid, String feedText, Set<String> mentionedVREGroups, Set<String> hashtags);
+	
 	/**
 	 * use to notify a user that someone commented on his post
 	 * 
@@ -240,10 +255,9 @@ public interface NotificationsManager {
 	 * use to notify a user he got one of his job finished
 	 *  
 	 * @param userIdToNotify the user you want to notify
-	 * @param executingApp the {@link ApplicationProfile} of the application from which the job was executed/lauched 
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyJobStatus(String userIdToNotify, ApplicationProfile executingJobApId, RunningJob job);
+	boolean notifyJobStatus(String userIdToNotify, RunningJob job);
 	
 	boolean notifyTDMTabularResourceSharing(String userIdToNotify, String tabularResourceName, String encodedTabularResourceParams) throws Exception;
 	/**
